@@ -582,11 +582,11 @@ static void on_response( GtkDialog* dlg, int response, FMPrefDlg* user_data )
                             file_browser->side_dir = NULL;
                         }
                         ptk_file_browser_update_views( NULL, file_browser );
+                        if ( file_browser->side_book )
+                            ptk_bookmark_view_update_icons( NULL, file_browser );
                     }
                 }
             }
-
-            update_bookmark_icons();            
             update_volume_icons();            
         }
 
