@@ -264,8 +264,12 @@ static void _ptk_file_list_file_changed( VFSDir* dir, VFSFileInfo* file,
     ptk_file_list_file_changed( dir, file, list );
 
     /* check if reloading of thumbnail is needed. */
-    if( vfs_file_info_is_image( file )
-        && vfs_file_info_get_size( file ) < list->max_thumbnail )
+    if ( list->max_thumbnail != 0 && (
+#ifdef HAVE_FFMPEG
+         vfs_file_info_is_video( file ) ||
+#endif
+         ( file->size /*vfs_file_info_get_size( file )*/ < list->max_thumbnail
+                                    && vfs_file_info_is_image( file ) ) ) )
     {
         if( ! vfs_file_info_is_thumbnail_loaded( file, list->big_thumbnail ) )
             vfs_thumbnail_loader_request( list->dir, file, list->big_thumbnail );
@@ -278,8 +282,12 @@ static void _ptk_file_list_file_created( VFSDir* dir, VFSFileInfo* file,
     ptk_file_list_file_created( dir, file, list );
 
     /* check if reloading of thumbnail is needed. */
-    if( vfs_file_info_is_image( file )
-        && vfs_file_info_get_size( file ) < list->max_thumbnail )
+    if ( list->max_thumbnail != 0 && (
+#ifdef HAVE_FFMPEG
+         vfs_file_info_is_video( file ) ||
+#endif
+         ( file->size /*vfs_file_info_get_size( file )*/ < list->max_thumbnail
+                                    && vfs_file_info_is_image( file ) ) ) )
     {
         if( ! vfs_file_info_is_thumbnail_loaded( file, list->big_thumbnail ) )
             vfs_thumbnail_loader_request( list->dir, file, list->big_thumbnail );
@@ -446,8 +454,12 @@ void ptk_file_list_get_value ( GtkTreeModel *tree_model,
     case COL_FILE_BIG_ICON:
         icon = NULL;
         /* special file can use special icons saved as thumbnails*/
-        if( list->max_thumbnail > vfs_file_info_get_size( info )
-            && info->flags == VFS_FILE_INFO_NONE )
+        if ( info->flags == VFS_FILE_INFO_NONE && (
+             list->max_thumbnail > info->size /*vfs_file_info_get_size( info )*/
+#ifdef HAVE_FFMPEG
+             || ( list->max_thumbnail != 0 && vfs_file_info_is_video( info ) )
+#endif
+             ) )
             icon = vfs_file_info_get_big_thumbnail( info );
 
         if( ! icon )
@@ -461,7 +473,11 @@ void ptk_file_list_get_value ( GtkTreeModel *tree_model,
     case COL_FILE_SMALL_ICON:
         icon = NULL;
         /* special file can use special icons saved as thumbnails*/
-        if( list->max_thumbnail > vfs_file_info_get_size( info ) )
+        if ( list->max_thumbnail > info->size /*vfs_file_info_get_size( info )*/
+#ifdef HAVE_FFMPEG
+             || ( list->max_thumbnail != 0 && vfs_file_info_is_video( info ) )
+#endif
+             )
             icon = vfs_file_info_get_small_thumbnail( info );
         if( !icon )
             icon = vfs_file_info_get_small_icon( info );
@@ -995,6 +1011,9 @@ void ptk_file_list_show_thumbnails( PtkFileList* list, gboolean is_big,
     VFSFileInfo* file;
     int old_max_thumbnail;
 
+    if ( !list )
+        return;
+    
     old_max_thumbnail = list->max_thumbnail;
     list->max_thumbnail = max_file_size;
     list->big_thumbnail = is_big;
@@ -1010,8 +1029,11 @@ void ptk_file_list_show_thumbnails( PtkFileList* list, gboolean is_big,
             for( l = list->files; l; l = l->next )
             {
                 file = (VFSFileInfo*)l->data;
-                if( vfs_file_info_is_image( file )
-                    && vfs_file_info_is_thumbnail_loaded( file, is_big ) )
+                if ( ( vfs_file_info_is_image( file )
+#ifdef HAVE_FFMPEG
+                       || vfs_file_info_is_video( file )
+#endif
+                     ) && vfs_file_info_is_thumbnail_loaded( file, is_big ) )
                 {
                     /* update the model */
                     ptk_file_list_file_changed( list->dir, file, list );
@@ -1020,15 +1042,18 @@ void ptk_file_list_show_thumbnails( PtkFileList* list, gboolean is_big,
         }
         return;
     }
-
     g_signal_connect( list->dir, "thumbnail-loaded",
                                     G_CALLBACK(on_thumbnail_loaded), list );
 
     for( l = list->files; l; l = l->next )
     {
         file = (VFSFileInfo*)l->data;
-        if( vfs_file_info_is_image( file )
-            && vfs_file_info_get_size( file ) < list->max_thumbnail )
+        if ( list->max_thumbnail != 0 && (
+#ifdef HAVE_FFMPEG
+             vfs_file_info_is_video( file ) ||
+#endif
+             ( file->size /*vfs_file_info_get_size( file )*/ < list->max_thumbnail
+                                        && vfs_file_info_is_image( file ) ) ) )
         {
             if( vfs_file_info_is_thumbnail_loaded( file, is_big ) )
                 ptk_file_list_file_changed( list->dir, file, list );
